({
    "title": "三菱PLC-MC",
    "key": "mitsubishi-mc",
    "driver": {
        "properties": {
            "settings": {
                "title": "设备配置",
                "type": "object",
                "properties": {
                    "ip": {
                        "type": "string",
                        "title": "设备IP"
                    },
                    "port": {
                        "type": "number",
                        "title": "端口",
                        "description": "1025～5548或5560～65534"
                    },
                    "frame": {
                        "type": "string",
                        "title": "帧类型",
                        "enum": [
                            '1E',
                            '3E',
                            '4E'
                        ]
                    },
                    "plcType": {
                        "type": "string",
                        "title": "plc类型",
                        "enum": [
                            "A",
                            "QnA",
                            "Q",
                            "L",
                            'R'
                        ]
                    },
                    "ascii": {
                        "type": "boolean",
                        "title": "ASCII码通信",
                        "description": "默认不选,即以二进制码通信"
                    },
                    "network_no": {
                        "type": "number",
                        "title": "网络编号",
                        "description": "[3E/4E]指定访问目标的网络编号"
                    },
                    "pc_station": {
                        "type": "number",
                        "title": "可编程控制器编号",
                        "description": "[3E/4E]指定访问目标的网络模块的站号"
                    },
                    "plc_module_no": {
                        "type": "number",
                        "title": "请求目标模块I/O编号",
                        "description": "[3E/4E]访问多点连接站的情况下，指定多点连接源模块的起始输入输出编号； 指定多CPU系统、冗余系统的CPU模块"
                    },
                    "plc_station": {
                        "type": "number",
                        "title": "请求目标模块站号",
                        "description": "[3E/4E]访问多点连接站的情况下，指定访问目标模块的站号"
                    },
                    "pointScale1E": {
                        "type": "number",
                        "title": "1E点数倍率",
                        "description": "[1E]进行数据采集时，部分型号的PLC允许的最大点数小于协议文档中的数值，可以用此项作为除数调整，缺省为1"
                    },
                    "oct_addr": {
                        "type": "string",
                        "title": "八进制地址",
                        "description": "将X和Y类型的软元件编号按照八进制而不是十进制处理",
                        "field": {
                            "defaultValue": "inactive"
                        },
                        "enum": ["active", "inactive"],
                        "enum_title": ["启用", "不启用"]
                    },
                    "interval": {
                        "type": "number",
                        "title": "采集周期",
                        "description": "不得小于5s"
                    },
                    "network": {
                        "type": "object",
                        "title": "通讯监控参数",
                        "properties": {
                            "timeout": {
                                "title": "通讯超时时间(s)",
                                "description": "经过多长时间仪表还没有任何数据上传，认定为通讯故障，默认为周期的3倍",
                                "type": "number"
                            }
                        },
                        "form": [{
                            "key": "timeout",
                            "validate": (v, vs) => {
                                const interval = vs && vs.settings && vs.settings.interval
                                return v <= interval ? '需大于采集周期' : null
                            }
                        }]
                    }
                }
            },
            "tags": {
                "title": "数据点",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "id": {
                            "type": "string",
                            "title": "标识"
                        },
                        "deviceName": {
                            "type": "string",
                            "title": "软元件名称",
                            "description": "由软元件代码和编号组成，如D0，M1000，D0.2"
                        },
                        "rw": {
                            "type": "boolean",
                            "title": "允许指令写入",
                            "description": "缺省为false"
                        },
                    },
                    "required": ["name", "id", "deviceName"]
                }
            },
            "commands": {
                "title": "命令",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "form": {},
                        "ops": {
                            "title": "指令",
                            "type": "array",
                            "items": {
                                "type": "object",
                                "properties": {
                                    "deviceName": {
                                        "type": "string",
                                        "title": "软元件名称",
                                        "description": "由软元件代码和编号组成，如D0，M1000，D0.2"
                                    },
                                    "value": {
                                        "type": "number",
                                        "title": "默认值",
                                        "description": "写入布尔值时会被转化为0或1"
                                    }
                                },
                                "required": ["deviceName", "value"]
                            }
                        }
                    }
                }
            }
        }
    },
    "model": {
        "properties": {
            "settings": {
                "title": "设备配置",
                "type": "object",
                "properties": {
                    "ip": {
                        "type": "string",
                        "title": "设备IP"
                    },
                    "port": {
                        "type": "number",
                        "title": "端口",
                        "description": "1025～5548或5560～65534"
                    },
                    "frame": {
                        "type": "string",
                        "title": "帧类型",
                        "enum": [
                            '1E',
                            '3E',
                            '4E'
                        ]
                    },
                    "plcType": {
                        "type": "string",
                        "title": "plc类型",
                        "enum": [
                            "A",
                            "QnA",
                            "Q",
                            "L",
                            'R'
                        ]
                    },
                    "ascii": {
                        "type": "boolean",
                        "title": "ASCII码通信",
                        "description": "默认不选,即以二进制码通信"
                    },
                    "network_no": {
                        "type": "number",
                        "title": "网络编号",
                        "description": "[3E/4E]指定访问目标的网络编号"
                    },
                    "pc_station": {
                        "type": "number",
                        "title": "可编程控制器编号",
                        "description": "[3E/4E]指定访问目标的网络模块的站号"
                    },
                    "plc_module_no": {
                        "type": "number",
                        "title": "请求目标模块I/O编号",
                        "description": "[3E/4E]访问多点连接站的情况下，指定多点连接源模块的起始输入输出编号； 指定多CPU系统、冗余系统的CPU模块"
                    },
                    "plc_station": {
                        "type": "number",
                        "title": "请求目标模块站号",
                        "description": "[3E/4E]访问多点连接站的情况下，指定访问目标模块的站号"
                    },
                    "pointScale1E": {
                        "type": "number",
                        "title": "1E点数倍率",
                        "description": "[1E]进行数据采集时，部分型号的PLC允许的最大点数小于协议文档中的数值，可以用此项作为除数调整，缺省为1"
                    },
                    "oct_addr": {
                        "type": "string",
                        "title": "八进制地址",
                        "description": "将X和Y类型的软元件编号按照八进制而不是十进制处理",
                        "field": {
                            "defaultValue": "inherit"
                        },
                        "enum": ["inherit", "inactive", "active"],
                        "enum_title": ["继承自上一级", "不启用", "启用"]
                    },
                    "interval": {
                        "type": "number",
                        "title": "采集周期",
                        "description": "不得小于5s"
                    },
                    "network": {
                        "type": "object",
                        "title": "通讯监控参数",
                        "properties": {
                            "timeout": {
                                "title": "通讯超时时间(s)",
                                "description": "经过多长时间仪表还没有任何数据上传，认定为通讯故障，默认为周期的3倍",
                                "type": "number"
                            }
                        },
                        "form": [{
                            "key": "timeout",
                            "validate": (v, vs) => {
                                const interval = vs && vs.settings && vs.settings.interval
                                return v <= interval ? '需大于采集周期' : null
                            }
                        }]
                    }
                },
                "required": ["ip", "port", "frame", "plcType"]
            },
            "tags": {
                "title": "数据点",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "id": {
                            "type": "string",
                            "title": "标识"
                        },
                        "deviceName": {
                            "type": "string",
                            "title": "软元件名称",
                            "description": "由软元件代码和编号组成，如D0，M1000，D0.2"
                        },
                        "rw": {
                            "type": "boolean",
                            "title": "允许指令写入",
                            "description": "缺省为false"
                        },
                    },
                    "required": ["name", "id", "deviceName"]
                }
            },
            "commands": {
                "title": "命令",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "form": {},
                        "ops": {
                            "title": "指令",
                            "type": "array",
                            "items": {
                                "type": "object",
                                "properties": {
                                    "deviceName": {
                                        "type": "string",
                                        "title": "软元件名称",
                                        "description": "由软元件代码和编号组成，如D0，M1000，D0.2"
                                    },
                                    "value": {
                                        "type": "number",
                                        "title": "默认值",
                                        "description": "写入布尔值时会被转化为0或1"
                                    }
                                },
                                "required": ["deviceName", "value"]
                            }
                        }
                    }
                }
            }
        }
    },
    "device": {
        "properties": {
            "settings": {
                "title": "设备配置",
                "type": "object",
                "properties": {
                    "ip": {
                        "type": "string",
                        "title": "设备IP"
                    },
                    "port": {
                        "type": "number",
                        "title": "端口",
                        "description": "1025～5548或5560～65534"
                    },
                    "frame": {
                        "type": "string",
                        "title": "帧类型",
                        "enum": [
                            '1E',
                            '3E',
                            '4E'
                        ]
                    },
                    "plcType": {
                        "type": "string",
                        "title": "plc类型",
                        "enum": [
                            "A",
                            "QnA",
                            "Q",
                            "L",
                            'R'
                        ]
                    },
                    "ascii": {
                        "type": "boolean",
                        "title": "ASCII码通信",
                        "description": "默认不选,即以二进制码通信"
                    },
                    "network_no": {
                        "type": "number",
                        "title": "网络编号",
                        "description": "[3E/4E]指定访问目标的网络编号"
                    },
                    "pc_station": {
                        "type": "number",
                        "title": "可编程控制器编号",
                        "description": "[3E/4E]指定访问目标的网络模块的站号"
                    },
                    "plc_module_no": {
                        "type": "number",
                        "title": "请求目标模块I/O编号",
                        "description": "[3E/4E]访问多点连接站的情况下，指定多点连接源模块的起始输入输出编号； 指定多CPU系统、冗余系统的CPU模块"
                    },
                    "plc_station": {
                        "type": "number",
                        "title": "请求目标模块站号",
                        "description": "[3E/4E]访问多点连接站的情况下，指定访问目标模块的站号"
                    },
                    "pointScale1E": {
                        "type": "number",
                        "title": "1E点数倍率",
                        "description": "[1E]进行数据采集时，部分型号的PLC允许的最大点数小于协议文档中的数值，可以用此项作为除数调整，缺省为1"
                    },
                    "oct_addr": {
                        "type": "string",
                        "title": "八进制地址",
                        "description": "将X和Y类型的软元件编号按照八进制而不是十进制处理",
                        "field": {
                            "defaultValue": "inherit"
                        },
                        "enum": ["inherit", "inactive", "active"],
                        "enum_title": ["继承自上一级", "不启用", "启用"]
                    },
                    "interval": {
                        "type": "number",
                        "title": "采集周期",
                        "description": "不得小于5s"
                    },
                    "network": {
                        "type": "object",
                        "title": "通讯监控参数",
                        "properties": {
                            "timeout": {
                                "title": "通讯超时时间(s)",
                                "description": "经过多长时间仪表还没有任何数据上传，认定为通讯故障，默认为周期的3倍",
                                "type": "number"
                            }
                        },
                        "form": [{
                            "key": "timeout",
                            "validate": (v, vs) => {
                                const interval = vs && vs.settings && vs.settings.interval
                                return v <= interval ? '需大于采集周期' : null
                            }
                        }]
                    }
                },
                "required": ["ip", "port", "frame", "plcType"]
            },
            "tags": {
                "title": "数据点",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "id": {
                            "type": "string",
                            "title": "标识"
                        },
                        "deviceName": {
                            "type": "string",
                            "title": "软元件名称",
                            "description": "由软元件代码和编号组成，如D0，M1000，D0.2"
                        },
                        "rw": {
                            "type": "boolean",
                            "title": "允许指令写入",
                            "description": "缺省为false"
                        },
                    },
                    "required": ["name", "id", "deviceName"]
                }
            },
            "commands": {
                "title": "命令",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "form": {},
                        "ops": {
                            "title": "指令",
                            "type": "array",
                            "items": {
                                "type": "object",
                                "properties": {
                                    "deviceName": {
                                        "type": "string",
                                        "title": "软元件名称",
                                        "description": "由软元件代码和编号组成，如D0，M1000，D0.2"
                                    },
                                    "value": {
                                        "type": "number",
                                        "title": "默认值",
                                        "description": "写入布尔值时会被转化为0或1"
                                    }
                                },
                                "required": ["deviceName", "value"]
                            }
                        }
                    }
                }
            }
        }
    }
})
